@@ -491,15 +491,30 @@ macro_rules! cmd {
 	($name:literal$sep:tt$t:tt)=>{
 		cmd!($name.into()=>$t)
 	};
+	($name:literal$sep:tt$t:tt)=>{
+		cmd!($name.into()=>$t)
+	};
+	($name:expr=>{$($t:tt)+})=>{
+		cmd!($name=>[$($t)+])
+	};
+	($name:expr=>($($t:tt)+))=>{
+		cmd!($name=>[$($t)+])
+	};
+	($name:expr=>[$(=)?$action:expr,<...,$($t:tt)+])=>{
+		cmd!($name=>[=$action,<$crate::crate_authors!(),$($t)+])
+	};
+	($name:expr=>[$(=)?$action:expr,<from_crate,$($t:tt)+])=>{
+		cmd!($name=>[=$action,<$crate::crate_authors!(),$($t)+])
+	};
 	(
 		$name:expr=>
 		[
 			$(=)?$action:expr,
 			<$authors:expr,
-			@$copyright:expr,
-			#$license:tt,
+			@$copyright:tt,
+			+$license:tt,
 			$(=)+$desc:expr,
-			~$usage:expr,
+			:$usage:expr,
 			l#$l_flags:expr,
 			c#$c_flags:expr,
 			&$alias:expr,
@@ -512,7 +527,7 @@ macro_rules! cmd {
 			String::from($name),
 			$crate::option_wrap!($action),
 			$authors.into(),
-			$copyright.into(),
+			$crate::copyright!($copyright),
 			$crate::license!$license,
 			$crate::option_wrap!($desc),
 			$usage.into(),
@@ -524,7 +539,50 @@ macro_rules! cmd {
 			$crate::option_wrap!($help),
 		)
 	};
+}
 
+#[macro_export]
+/// Create copyright macro
+macro_rules! copyright {
+	($raw_str:literal) => {
+		$raw_str.to_string()
+	};
+	(...) => {
+		$crate::copyright!("Copyright (c) ", "", $crate::crate_authors!())
+	};
+	({$($t:tt)+})=>{
+		copyright!([$($t:tt)+])
+	};
+	(($($t:tt)+))=>{
+		copyright!([$($t:tt)+])
+	};
+	([$year:expr]) => {
+		$crate::copyright!($year, $crate::crate_authors!())
+	};
+	([$year:expr,$holder:ident]) => {
+		$crate::copyright!($year, stringify!($holder))
+	};
+	([$year:expr,$holder:expr]) => {
+		copyright!($year, $holder)
+	};
+	($year:expr,$holder:ident) => {
+		copyright!($year, stringify!($holder))
+	};
+	($year:expr,$holder:expr) => {
+		$crate::copyright!("Copyright (c)", $year, $holder)
+	};
+	([$prefix:expr, $year:expr,$holder:ident]) => {
+		$crate::copyright!($prefix, $year, stringify!($holder))
+	};
+	([$prefix:expr, $year:expr,$holder:expr]) => {
+		$crate::copyright!($prefix, $year, $holder)
+	};
+	($prefix:expr, $year:expr,$holder:ident) => {
+		copyright!($prefix, $year, stringify!($holder))
+	};
+	($prefix:expr, $year:expr,$holder:expr) => {
+		concat!($prefix, " ", $year, " ", $holder).to_owned()
+	};
 }
 
 #[macro_export]
@@ -534,7 +592,7 @@ macro_rules! flags {
 		$crate::vector![$($crate::flag!$flag_arg),*]
 	};
 	($($flag_name:ident$flag_arg:tt),* $(,)?)=>{
-		flags!($([$flag_name$flag_arg]),*);
+		flags!($([$flag_name:$flag_arg]),*);
 	};
 	($flag_name:ident$flag_arg:tt,$($t:tt)+)=>{
 		flags!($flag_name=>$flag_arg,$($t)+)
@@ -544,39 +602,183 @@ macro_rules! flags {
 	};
 }
 
+#[macro_export]
+/// string_from macro. based on Strong::from, but no arg can generate String::new()
+macro_rules! string_from {
+	() => {
+		String::new()
+	};
+	($from:expr)=>{
+		String::from($from)
+	};
+	($($from_tt:tt)+)=>{
+		String::from($($from_tt)+)
+	};
+}
+
 #[macro_export]
 /// Helps for creating flag.
 macro_rules! flag {
-	($name:ident=>[$type:ident,$(-$s:ident),*,$(--$long:ident),*, =$description:expr,@$default:expr]) => {
+	($(@)?$name:ident$flag_arg:tt)=>{
+		flag!(stringify!($name)=>$flag_arg)
+	};
+	($(@)?$name:ident=:[$($t:tt)+])=>{
+		flag!(stringify!($name)=>[$($t)+])
+	};
+	($(@)?$name:ident$($sep:tt)?[$($t:tt)+])=>{
+		flag!(stringify!($name)=>[$($t)+])
+	};
+	($(@)?$name:ident=>$flag_arg:tt)=>{
+		flag!(stringify!($name)=>$flag_arg)
+	};
+	($(@)?$name:expr=>{$($t:tt)+})=>{
+		flag!($name=>[$($t)+])
+	};
+	($(@)?$name:expr=>($($t:tt)+))=>{
+		flag!($name=>[$($t)+])
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$($description:expr)?,$(-$s:ident),*$(,)?$(--$l:ident),*?$($default:expr)?]) => {
+		flag!(
+			String::from($name)=>[
+				$crate::string_from!($($description)?),
+				$crate::vector![$($crate::char!($s)),*],
+				$crate::vector![$(stringify!($l).to_owned()),*],
+				$crate::flag_type!($type),
+				$crate::flag_value!($type, $($default)?)
+			]
+		)
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$($description:expr)?,$(-$s:ident),*$(,)?$(--$l:ident),*,?$($default:expr)?])=>{
+		flag!($name=>[$type,$($description)?,$(-$s),*,$(--$l),*$(?$default)?])
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$($description:expr)?,$(-$s:ident),*$(,)?$(--$l:ident),*@$($default:expr)?]) => {
+		flag!($name=>[$type,$($description)?,$(-$s),*,$(--$l),*?$($default)?])
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$($description:expr)?,$(-$s:ident),*$(,)?$(--$l:ident),*,@$($default:expr)?]) => {
+		flag!($name=>[$type,$($description)?,$(-$s),*$(,)?$(--$l:ident),*,@$($default)?])
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$($description:expr)?,$($default:expr)?])=>{
+		flag![$name=>[$type,$($description)?,?$($default)?]]
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$($description:expr)?,@$default:expr])=>{
+		flag![$name=>[$type,$($description)?,?$default]]
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$(-$s:ident),*$(,)?$(--$l:ident),*,=$($description:expr)?,$(?)?$default:expr]) => {
+		flag!($name=>[$type,$($description)?,$(-$s),*,$(--$l),*,?$default])
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$(-$s:ident),*$(,)?$(--$l:ident),*,$($description:ident)?,$(?)?$default:expr]) => {
+		flag!($name=>[$type,$(-$s),*,$(--$l),*,=$($description)?,?$default])
+	};
+	($(@)?$name:expr=>[$(>)?$type:ident,$(=)?$($description:expr)?])=>{
+		flag!($name=>[$type,$($description)?,$crate::default_value!($type)])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,$(-$s:ident),*$(,)?$(--$l:ident),*$(>)?$type:ident$(,)??$default:expr])=>{
+		flag!($name=>[$type,$description,$(-$s),* $(--$l),*?$default])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,$(-$s:ident),*$(,)?$(--$l:ident),*,$(>)?$type:ident$(,)??$default:expr])=>{
+		flag!($name=>[$description,$(-$s),* $(--$l),*$type?$default])
+	};
+	($(@)?$name:expr=>[$(-$s:ident),*$(,)?$(--$l:ident),*,=$description:expr,$(>)?$type:ident$(,)??$default:expr])=>{
+		flag!($name=>[$description,$(-$s),*$(--$l),*$type?$default])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,$(-$s:ident),*$(,)?$(--$l:ident),*$(>)?$type:ident$(,)?])=>{
+		flag!($name=>[$description,$(-$s),* $(--$l),* $type?$crate::default_value!($type)])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,$(-$s:ident),*$(,)?$(--$l:ident),*,$(>)?$type:ident$(,)?])=>{
+		flag!($name=>[$description,$(-$s),* $(--$l),* $type])
+	};
+	($(@)?$name:expr=>[$(-$s:ident),*$(,)?$(--$l:ident),*,=$description:expr,$(>)?$type:ident$(,)?])=>{
+		flag!($name=>[$description,$(-$s),*$(--$l),*$type])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,$(-$s:ident),*$(,)?$(--$l:ident),* ?false])=>{
+		flag!($name=>[$description,$(-$s),*$(--$l),* >bool?false])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,$(-$s:ident),*$(,)?$(--$l:ident),*,?false])=>{
+		flag!($name=>[$description,$(-$s),*$(--$l),* >bool?false])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr,?false])=>{
+		flag!($name=>[$description,>bool?false])
+	};
+	($(@)?$name:expr=>[$i:ident$(,)?])=>{
+		$crate::_flag_one_ident!($name=>[$i])
+	};
+	($(@)?$name:expr=>[>$type:ident])=>{
+		flag!($name=>[$type,])
+	};
+	($(@)?$name:expr=>[$(=)?$description:expr])=>{
+		flag!($name=>[str,$description])
+	};
+	($name:expr=>[$(=)?$description:expr,$(s#)?$short_alias:expr,$(l#)?$long_alias:expr,$(>)?$type:expr,$(?)?$default:expr])=>{
 		Flag::with_all_field(
-			String::from(stringify!($name)),
-			String::from($description),
-			$crate::vector![$($crate::char!($s)),*],
-			$crate::vector![$(stringify!($long).to_owned()),*],
-			$crate::flag_type!($type),
-			$crate::flag_value!($type, $default),
-		);
+			$name,
+			$description,
+			$short_alias,
+			$long_alias,
+			$type,
+			$default
+		)
 	};
-	($(@)?$name:ident=>[$type:ident$(,)?$(-$s:ident),*$(,)?$(--$long:ident),*, =$description:expr,$(@)?$default:expr]) => {
-		flag!($name=>[$type,$(-$s),*,$(--$long),*, =$description, @$default])
+}
+
+#[macro_export]
+/// sub macro for flag
+macro_rules! _flag_one_ident {
+	($(@)?$name:expr=>[bool])=>{
+		$crate::flag!($name=>[>bool])
 	};
-	($(@)?$name:ident=>[$type:ident$(,)?$(-$s:ident),*$(,)?$(--$long:ident),*, =$description:expr,$(?)?$default:expr]) => {
-		flag!($name=>[$type,$(-$s),*,$(--$long),*, =$description, @$default])
+	($(@)?$name:expr=>[b])=>{
+		$crate::flag!($name=>[>b])
 	};
-	($(@)?$name:ident=>{$($t:tt)+})=>{
-		flag!($name=>[$($t)+])
+	($(@)?$name:expr=>[B])=>{
+		$crate::flag!($name=>[>B])
 	};
-	($(@)?$name:ident=>($($t:tt)+)) => {
-		flag!($name=>[$($t)+])
+	($(@)?$name:expr=>[Bool])=>{
+		$crate::flag!($name=>[>Bool])
 	};
-	($(@)?$name:ident:$args:tt)=>{
-		flag!($name=>$args)
+	($(@)?$name:expr=>[int])=>{
+		$crate::flag!($name=>[>int])
 	};
-	($(@)?$name:ident=$args:tt)=>{
-		flag!($name=>$args)
+	($(@)?$name:expr=>[i])=>{
+		$crate::flag!($name=>[>i])
 	};
-	($(@)?$name:ident$args:tt)=>{
-		flag!($name=>$args)
+	($(@)?$name:expr=>[Integer])=>{
+		$crate::flag!($name=>[>Integer])
+	};
+	($(@)?$name:expr=>[I])=>{
+		$crate::flag!($name=>[>I])
+	};
+	($(@)?$name:expr=>[integer])=>{
+		$crate::flag!($name=>[>integer])
+	};
+	($(@)?$name:expr=>[Int])=>{
+		$crate::flag!($name=>[>Int])
+	};
+	($(@)?$name:expr=>[>$type:ident])=>{
+		$crate::flag!($name=>[$type,""])
+	};
+	($(@)?$name:expr=>[float])=>{
+		$crate::flag!($name=>[>float])
+	};
+	($(@)?$name:expr=>[f])=>{
+		$crate::flag!($name=>[>f])
+	};
+	($(@)?$name:expr=>[F])=>{
+		$crate::flag!($name=>[>F])
+	};
+	($(@)?$name:expr=>[Float])=>{
+		$crate::flag!($name=>[>Float])
+	};
+	($(@)?$name:expr=>[Str])=>{
+		$crate::flag!($name=>[>Str])
+	};
+	($(@)?$name:expr=>[string])=>{
+		$crate::flag!($name=>[>string])
+	};
+	($(@)?$name:expr=>[String])=>{
+		$crate::flag!($name=>[>String])
+	};
+	($(@)?$name:expr=>[$description:ident])=>{
+		$crate::flag!($name=>[str,$description])
 	}
 }
 
@@ -587,7 +789,10 @@ macro_rules! flag_type {
 		$crate::flag_type!(Bool)
 	};
 	(b) => {
-		flag_type!(b)
+		$crate::flag_type!(bool)
+	};
+	(B) => {
+		flag_type!(boool)
 	};
 	(int) => {
 		$crate::flag_type!(Int)
@@ -595,6 +800,9 @@ macro_rules! flag_type {
 	(i) => {
 		flag_type!(int)
 	};
+	(I) => {
+		flag_type!(int)
+	};
 	(Integer) => {
 		flag_type!(int)
 	};
@@ -607,17 +815,26 @@ macro_rules! flag_type {
 	(f) => {
 		flag_type!(f)
 	};
-	(string) => {
-		$crate::flag_type!(String)
+	(F) => {
+		flag_type!(f)
 	};
 	(str) => {
-		flag_type!(string)
+		$crate::flag_type!(string)
 	};
 	(Str) => {
 		flag_type!(string)
 	};
+	(s) => {
+		flag_type!(str)
+	};
+	(S) => {
+		flag_type!(str)
+	};
+	(string) => {
+		$crate::flag_type!(String)
+	};
 	($i:ident) => {
-		FlagType::$i
+		$crate::FlagType::$i
 	};
 }
 
@@ -628,10 +845,10 @@ macro_rules! flag_value {
 		$crate::FlagValue::Bool($val)
 	};
 	(b, $val:expr) => {
-		flag_value!(bool, $val)
+		$crate::flag_value!(bool, $val)
 	};
 	(Bool,$val:expr) => {
-		flag_value!(bool, $val)
+		$crate::flag_value!(bool, $val)
 	};
 	(true) => {
 		flag_value!(bool, true)
@@ -663,6 +880,9 @@ macro_rules! flag_value {
 	(Float, $val:expr) => {
 		flag_value!(float, $val)
 	};
+	(str,$val:literal) => {
+		$crate::flag_value!(str, $val.into())
+	};
 	(str, $val:expr) => {
 		$crate::FlagValue::String($val)
 	};
@@ -678,6 +898,76 @@ macro_rules! flag_value {
 	(string, $val:expr) => {
 		flag_value!(str, $val)
 	};
+	($i:ident$(,)?) => {
+		$crate::flag_value!($i, $crate::default_value!($i))
+	};
+}
+
+#[macro_export]
+/// Creates default_flag_value
+macro_rules! default_flag_value {
+	($type:ident) => {
+		$crate::flag_value!($type, $crate::default_value!($type))
+	};
+}
+
+#[macro_export]
+/// get Default falue from type
+macro_rules! default_value {
+	(b) => {
+		$crate::default_value!(bool)
+	};
+	(Bool) => {
+		$crate::default_value!(bool)
+	};
+	(bool) => {
+		bool::default()
+	};
+	(true) => {
+		default_value!(bool)
+	};
+	(false) => {
+		default_value!(bool)
+	};
+	(i) => {
+		default_value!(int)
+	};
+	(Int) => {
+		default_value!(int)
+	};
+	(Integer) => {
+		default_value!(int)
+	};
+	(integer) => {
+		default_value!(int)
+	};
+	(int) => {
+		isize::default()
+	};
+	(f) => {
+		default_value!(float)
+	};
+	(Float) => {
+		default_value!(float)
+	};
+	(float) => {
+		f64::default()
+	};
+	(s) => {
+		default_value!(str)
+	};
+	(Str) => {
+		default_value!(str)
+	};
+	(String) => {
+		default_value!(str)
+	};
+	(string) => {
+		default_value!(str)
+	};
+	(str) => {
+		String::default()
+	};
 }
 
 #[macro_export]
